﻿
using Accordion.Model;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

// The User Control item template is documented at http://go.microsoft.com/fwlink/?LinkId=234236

namespace Accordion.Controls
{
    public sealed partial class DynamicRadioButton : UserControl
    {
        public string GroupId
        {
            get { return (string)GetValue(GroupIdProperty); }
            set { SetValue(GroupIdProperty, value); }
        }

        // Using a DependencyProperty as the backing store for GroupId.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty GroupIdProperty =
            DependencyProperty.Register("GroupId", typeof(string), typeof(DynamicRadioButton), new PropertyMetadata(null));

        public ObservableCollection<AvailableOption> Options
        {
            get { return (ObservableCollection<AvailableOption>)GetValue(OptionsProperty); }
            set { SetValue(OptionsProperty, value); }
        }

        // Using a DependencyProperty as the backing store for Options.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty OptionsProperty =
            DependencyProperty.Register("Options", typeof(ObservableCollection<AvailableOption>), typeof(DynamicRadioButton), new PropertyMetadata(null));

        public string Value
        {
            get { return (string)GetValue(ValueProperty); }
            set { SetValue(ValueProperty, value); }
        }

        // Using a DependencyProperty as the backing store for Value.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty ValueProperty =
            DependencyProperty.Register("Value", typeof(string), typeof(DynamicRadioButton), new PropertyMetadata(null));

        public DynamicRadioButton()
        {
            this.InitializeComponent();
        }

        private void RadioButton_Checked(object sender, RoutedEventArgs e)
        {
            var radioButton = sender as RadioButton;

            var value = radioButton.DataContext as AvailableOption;

            Value = value.Value;
        }

        private void RadioButton_Loading(FrameworkElement sender, object args)
        {
            var radioButton = sender as RadioButton;

            var value = radioButton.DataContext as AvailableOption;

            if (value.Value == Value)
            {
                radioButton.IsChecked = true;
            }
        }
    }
}
