﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Text;
using System.Threading.Tasks;
using Windows.Data.Json;
using Windows.Storage;

namespace Accordion.Model
{
    public class InspectionPhoto : INotifyPropertyChanged
    {
        private const string photoKey = "photo";
        private const string nameKey = "name";
        private const string captionKey = "caption";
        private const string pathKey = "path";

        private string path;
        private string caption;
        private string name;

        public StorageFile PhotoStorageFile { get; set; }

        public event PropertyChangedEventHandler PropertyChanged;

        public InspectionPhoto()
        {
            name = string.Empty;
            caption = string.Empty;
        }

        public InspectionPhoto(string name) : this()
        {
            Name = name;
        }

        public InspectionPhoto(JsonObject photoObject) : this()
        {
            JsonObject photo = photoObject.GetNamedObject(photoKey, null);

            if (photo != null)
            {
                Name = photo.GetNamedString(nameKey, "");
                Caption = photo.GetNamedString(captionKey, "");
                Path = photo.GetNamedString(pathKey, "");
            }
        }

        public JsonObject ToJsonObject()
        {
            var photoObject = new JsonObject();
            photoObject.SetNamedValue(pathKey, JsonValue.CreateStringValue(Path));
            photoObject.SetNamedValue(nameKey, JsonValue.CreateStringValue(Name));
            photoObject.SetNamedValue(captionKey, JsonValue.CreateStringValue(Caption));

            var jsonObject = new JsonObject();
            jsonObject.SetNamedValue(photoKey, photoObject);

            return jsonObject;
        }


        public InspectionPhoto(string name, string path, StorageFile photo) : this(name)
        {
            this.Name = name;
            this.Path = path;
            this.PhotoStorageFile = photo;
        }



        public string Name
        {
            get
            {
                return name;
            }
            set
            {
                if (value != name)
                {
                    name = value;
                    NotifyPropertyChanged();
                }
            }
        }

        public string Path
        {
            get
            {
                return path;
            }
            set
            {
                if (value != path)
                {
                    path = value;
                    NotifyPropertyChanged();
                }
            }
        }

        public string Caption
        {
            get
            {
                return caption;
            }
            set
            {
                if (value != caption)
                {
                    caption = value;
                    NotifyPropertyChanged();
                }
            }
        }

        private void NotifyPropertyChanged([CallerMemberName] string propertyName = "")
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}
